@@ -4,7 +4,7 @@
  * Refer to rpncalc.c for copyrights and license permissions.           *
  ************************************************************************/
 
-/* $Id: stack.h,v 1.4 2000/04/02 16:13:01 david Rel $
+/* $Id: stack.h,v 1.4 2000/04/02 16:13:01 david Rel david $
  * $Log: stack.h,v $
  * Revision 1.4  2000/04/02 16:13:01  david
  * Removed declaration of pushtostack.
@@ -26,7 +26,7 @@ struct elm
   struct elm *prev, *next;
 };
 
-enum BASE { DEC, HEX, OCT, CHAR };	/* current base (dec,oct..) */
+enum BASE { DEC, HEX, OCT, CHAR, BIN };	/* current base (dec,oct..) */
 
 double push(double elem);
 double pop(void);
@@ -47,5 +47,6 @@ double sethex(void);
 double setdec(void);
 double setoct(void);
 double setchar(void);
+double setbin(void);
 
 double prec(double p);
