@@ -4,8 +4,14 @@
  * Refer to rpncalc.c for copyrights and license permissions.           *
  ************************************************************************/
 
-/* $Id: utils.h,v 1.4 1997/01/19 18:58:58 david Rel $
+/* $Id: utils.h,v 1.6 2000/04/02 16:13:19 david Rel $
  * $Log: utils.h,v $
+ * Revision 1.6  2000/04/02 16:13:19  david
+ * Added conditional #ifdef HAVE_READLINE to prototype readline.
+ *
+ * Revision 1.5  1999/03/06 14:31:06  david
+ * Deleted the lint-comments.
+ *
  * Revision 1.4  1997/01/19 18:58:58  david
  * Changed dupstr(char *) to dupstr(const char *)
  *
@@ -25,9 +31,10 @@
  * Initial revision
  * */
 
-/*@out@*/ void *xmalloc(size_t size);
-/*@out@*/ void *xrealloc(void *ptr, size_t size);
+void *xmalloc(size_t size);
+void *xrealloc(void *ptr, size_t size);
+char *xstrdup(const char *s);
 
-char *dupstr(const char *s);
-
-/*@null@*/ char *getline(void);
+#ifndef HAVE_READLINE
+char *readline(char *prompt);
+#endif
